// variables provided by g3d's vertex shader
varying vec4 worldPosition; // fragpos
varying vec3 vertexNormal;  // normal

// the model matrix comes from the camera automatically
uniform mat4 modelMatrix;

extern vec3 lightPosition;
extern float ambient = 0.2; // ambient strength, set externally, based on position
extern vec3 ambientLightColor; // ambient light color, set externally
extern vec3 lightColor; // light source color, set externally, based on position

vec4 effect(vec4 color, Image tex, vec2 texcoord, vec2 pixcoord) {
	
	// diffuse lighting
    vec3 norm = normalize(vertexNormal);
	vec3 lightDir = normalize(lightPosition.xyz - worldPosition.xyz);
	
	float diff = max(dot(norm, lightDir), 0.0);
	vec3 diffuse = diff* lightColor;
	
	// ambient lighting
	// calculate true value of ambient color, based on strength and light source color
	vec3 ambientcolor = ambient * ambientLightColor;    
    // get color from the texture, referred as "objectColor" in the tutorial
    vec4 objectColor = Texel(tex, texcoord);
    // if this pixel is invisible, get rid of it
    if (objectColor.a == 0.0) { discard; }

    // in LOVE objectColor is vec4
    vec3 result = (ambientcolor + diffuse) * vec3(objectColor);
	
	
    return vec4(result, 1.0);
}